// -*- C++ -*-
#include "tao/Network_Priority_Protocols_Hooks.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO_Network_Priority_Protocols_Hooks::
~TAO_Network_Priority_Protocols_Hooks ()
{
}

TAO_END_VERSIONED_NAMESPACE_DECL
